@@ -82,7 +82,9 @@ class AskReview:
                 x["youtrack"] for x in users if text.lower() in x["youtrack"].lower()
             ]
         )
-        reviewers = self._frequent_reviewers.select_reviewers(autocomplete=completer)
+        reviewers = self._frequent_reviewers.select_reviewers(
+            users, autocomplete=completer
+        )
 
         if not reviewers:
             logger.warning("You must enter at least one reviewer")
