@@ -22,7 +22,7 @@ class CreateBranch:
         if not self._git.is_detached() and self._git.is_dirty():
             # Default behaviour is to pull when not detached.
             # Can't do that with uncommitted changes.
-            logger.error("You have some uncommited changes, I can't continue")
+            logger.error("You have some uncommitted changes, I can't continue")
             sys.exit(-1)
 
         try:
@@ -69,7 +69,7 @@ class CreateBranch:
         )
 
     def _prompt_custom_card(self):
-        prompt_utils.ask_questions_input(
+        return prompt_utils.ask_questions_input(
             "Insert the YouTrack issue number:", self._config.user["default_slug"]
         )
 
