@@ -270,6 +270,21 @@ class GitHandler:
             sys.exit(-1)
 
 
+def get_root_folder(directory):
+    return (
+        subprocess.check_output(
+            ["git", "rev-parse", "--show-superproject-working-tree"], cwd=directory
+        )
+        .decode("utf-8")
+        .strip()
+        or subprocess.check_output(
+            ["git", "rev-parse", "--show-toplevel"], cwd=directory
+        )
+        .decode("utf-8")
+        .strip()
+    )
+
+
 def is_repo(directory):
     try:
         subprocess.run(
